﻿using System;
using System.IO;
using TheBeerHouse;
using TheBeerHouse.BLL.Store;
using TheBeerHouse.Store;
using TheBeerHouse.UI;

partial class Admin_AddEditDepartment : AdminPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            if (DepartmentId > 0)
            {
                BindDepartment();
            }
            else
            {
                ClearItems();
            }
        }
    }

    protected void ClearItems()
    {
        // txtDepartmentID.Text = String.Empty
        ltlAddedDate.Text = string.Empty;
        txtTitle.Text = string.Empty;
        txtImportance.Text = string.Empty;
        txtDescription.Text = string.Empty;
        iThumbnail.Visible = false;
        ltlUpdatedDate.Text = string.Empty;


        ltlStatus.Text = "Create a New Department.";
    }

    protected void BindDepartment()
    {
        using (DepartmentRepository lDepartmentrpt = new DepartmentRepository())
        {
            Department lDepartment = lDepartmentrpt.GetDepartmentById(DepartmentId);

            if ((lDepartment != null))
            {
                ltlDepartmentID.Text = lDepartment.DepartmentID.ToString();
                ltlAddedDate.Text = lDepartment.AddedDate.ToShortDateString();
                txtTitle.Text = lDepartment.Title;
                txtImportance.Text = lDepartment.Importance.ToString();
                txtDescription.Text = lDepartment.Description;

                if (string.IsNullOrEmpty(lDepartment.ImageUrl) == false)
                {
                    iThumbnail.ImageUrl = lDepartment.ImageUrl;
                    iThumbnail.Visible = true;
                }
                else
                {
                    iThumbnail.Visible = false;
                }

                ltlActive.Text = lDepartment.Active.ToString();
                ltlAddedBy.Text = lDepartment.AddedBy;
                ltlAddedDate.Text = lDepartment.AddedDate.ToShortDateString();
                ltlUpdatedDate.Text = lDepartment.UpdatedDate.ToShortDateString();
                ltlUpdatedBy.Text = lDepartment.UpdatedBy;

                ltlStatus.Text = "Edit The Department";
            }
            else
            {
                DepartmentId = 0;
                ltlStatus.Text = "Create a New Department";
            }
        }
    }

    protected void ManageDepartments()
    {
        Response.Redirect("ManageDepartment.aspx");
    }

    protected void UpdateDepartment()
    {
        using (DepartmentRepository lDepartmentrpt = new DepartmentRepository())
        {
            Department lDepartment = new Department();

            if (DepartmentId > 0)
            {
                lDepartment = lDepartmentrpt.GetDepartmentById(DepartmentId);
            }
            else
            {
                lDepartment = new Department();
            }

            lDepartment.DepartmentID = DepartmentId;
            lDepartment.AddedDate = DateTime.Parse(ltlAddedDate.Text);
            lDepartment.Title = txtTitle.Text;
            lDepartment.Importance = int.Parse(txtImportance.Text);
            lDepartment.Description = txtDescription.Text;
            lDepartment.UpdatedDate = DateTime.Parse(ltlUpdatedDate.Text);

            if (fPicture.HasFile)
            {
                string lFilePath = Path.Combine(Helpers.GetPhyscialPath("Store\\Departments"),
                                                Helpers.FormatSpacesForURL(lDepartment.Title) +
                                                Path.GetExtension(fPicture.FileName));

                if (File.Exists(lFilePath))
                {
                    File.Delete(lFilePath);
                }

                fPicture.SaveAs(lFilePath);


                lDepartment.ImageUrl = Path.Combine("~/Store/Departments",
                                                    Helpers.FormatSpacesForURL(lDepartment.Title) +
                                                    Path.GetExtension(fPicture.FileName));
            }

            lDepartment.UpdatedBy = UserName;
            lDepartment.UpdatedDate = DateTime.Now;

            if (lDepartment.DepartmentID > 0)
            {
                if ((lDepartmentrpt.AddDepartment(lDepartment) != null))
                {
                    IndicateUpdated(lDepartmentrpt, "Department", ltlStatus, cmdDelete);
                }
                else
                {
                    IndicateNotUpdated(lDepartmentrpt, "Department", ltlStatus);
                }
            }
            else
            {
                lDepartment.Active = true;
                lDepartment.AddedBy = UserName;
                lDepartment.AddedDate = DateTime.Now;
                if ((lDepartmentrpt.AddDepartment(lDepartment) != null))
                {
                    IndicateUpdated(lDepartmentrpt, "Department", ltlStatus, cmdDelete);
                }
                else
                {
                    IndicateNotUpdated(lDepartmentrpt, "Department", ltlStatus);
                }
            }
        }
    }

    protected void GoToDepartmentList()
    {
        Response.Redirect("ManageDepartment.aspx");
    }

    protected void DeleteDepartment()
    {
        using (DepartmentRepository lDepartmentrpt = new DepartmentRepository())
        {
            lDepartmentrpt.DeleteDepartment(lDepartmentrpt.GetDepartmentById(DepartmentId));
        }
        GoToDepartmentList();
    }

    protected void cmdDelete_Click(object sender, EventArgs e)
    {
        DeleteDepartment();
    }

    protected void cmdUpdate_Click(object sender, EventArgs e)
    {
        UpdateDepartment();
    }

    protected void cmdCancel_Click(object sender, EventArgs e)
    {
        GoToDepartmentList();
    }

}