﻿using System;
using TheBeerHouse;
using System.IO;
using TheBeerHouse.Store;
using TheBeerHouse.UI;

partial class Admin_AddEditProduct : AdminPage
{
    protected void Page_Load(object sender, System.EventArgs e)
    {
        if (!IsPostBack)
        {
            if (ProductId > 0)
            {
                BindProduct();
            }
            else
            {
                ClearItems();
            }
        }
    }

    protected void BindDepartments()
    {
        BindDepartments(0);
    }

    protected void BindDepartments(int vDepartmentId)
    {
        using (DepartmentRepository lDepartmentrpt = new DepartmentRepository())
        {
            ddlDepartment.DataValueField = "DepartmentId";
            ddlDepartment.DataTextField = "Title";
            ddlDepartment.DataSource = lDepartmentrpt.GetDepartments();
            ddlDepartment.DataBind();
            ddlDepartment.Items.Insert(0, "Select a Department");
            rfvDepartment.InitialValue = vDepartmentId.ToString();

            ddlDepartment.SelectedValue = vDepartmentId.ToString();
        }
    }

    protected void ClearItems()
    {
        ltlProductID.Text = string.Empty;
        ddlDepartment.ClearSelection();
        txtTitle.Text = string.Empty;
        txtDescription.Value = string.Empty;
        txtSKU.Text = string.Empty;
        txtUnitPrice.Text = "0";
        txtDiscountPercentage.Text = "0";
        txtUnitsInStock.Text = string.Empty;
        iThumbnail.Visible = false;
        ltlVotes.Text = string.Empty;
        ltlTotalRating.Text = string.Empty;
        ltlUpdatedDate.Text = string.Empty;

        BindDepartments();


        ltlStatus.Text = "Create a New Product.";
    }

    protected void BindProduct()
    {
        using (ProductsRepository Productrpt = new ProductsRepository())
        {
            Product lProduct = Productrpt.GetProductById(ProductId);

            if ((lProduct != null))
            {
                ltlProductID.Text = lProduct.ProductID.ToString();
                ltlAddedDate.Text = lProduct.AddedDate.ToString();
                BindDepartments(lProduct.DepartmentId);
                txtTitle.Text = lProduct.Title;
                txtDescription.Value = lProduct.Description;
                txtSKU.Text = lProduct.SKU;
                txtUnitPrice.Text = lProduct.UnitPrice.ToString();
                txtDiscountPercentage.Text = lProduct.DiscountPercentage.ToString();
                txtUnitsInStock.Text = lProduct.UnitsInStock.ToString();

                if (string.IsNullOrEmpty(lProduct.SmallImageUrl) == false)
                {
                    if (lProduct.SmallImageUrl.Contains("~"))
                    {
                        iThumbnail.ImageUrl = lProduct.SmallImageUrl;
                    }
                    else
                    {
                        iThumbnail.ImageUrl = StoreHelper.GetProductImageURL(lProduct.SmallImageUrl);
                    }
                }
                else
                {
                    iThumbnail.Visible = false;
                }

                ltlVotes.Text = lProduct.Votes.ToString();
                ltlTotalRating.Text = lProduct.TotalRating.ToString();
                ltlUpdatedDate.Text = lProduct.UpdatedDate.ToShortDateString();

                ltlActive.Text = lProduct.Active.ToString();
                ltlAddedBy.Text = lProduct.AddedBy;
                ltlUpdatedBy.Text = lProduct.UpdatedBy;

                ltlStatus.Text = "Edit The Product";
            }
            else
            {
                ProductId = 0;
                ltlStatus.Text = "Create a New Product";
            }
        }
    }

    protected void ManageProducts()
    {
        Response.Redirect("ManageProducts.aspx");
    }

    protected void UpdateProduct()
    {
        using (ProductsRepository lProductrpt = new ProductsRepository())
        {
            Product lProduct = new Product();

            if (ProductId > 0)
            {
                lProduct = lProductrpt.GetProductById(ProductId);
            }
            else
            {
                lProduct = new Product();
            }

            lProduct.ProductID = ProductId;

            lProduct.DepartmentId = int.Parse(ddlDepartment.SelectedValue);
            lProduct.Title = txtTitle.Text;
            lProduct.Description = txtDescription.Value;
            lProduct.SKU = txtSKU.Text;
            lProduct.UnitPrice = decimal.Parse(txtUnitPrice.Text);
            lProduct.DiscountPercentage = int.Parse(txtDiscountPercentage.Text);
            lProduct.UnitsInStock = int.Parse(txtUnitsInStock.Text);
            lProduct.Votes = int.Parse(ltlVotes.Text);
            lProduct.TotalRating = int.Parse(ltlTotalRating.Text);

            if (fImage.HasFile)
            {
                string lFullImagePath = Path.Combine(StoreHelper.GetProductImagesDirectory(), fImage.FileName);
                fImage.SaveAs(lFullImagePath);

                lProduct.FullImageUrl = StoreHelper.GetProductImageURL(fImage.FileName);
            }

            lProduct.UpdatedBy = UserName;

            if (lProduct.ProductID > 0)
            {
                lProduct.UpdatedDate = DateTime.Now;
                lProduct.UpdatedBy = UserName;

                if ((lProductrpt.AddProduct(lProduct) != null))
                {
                    IndicateUpdated(lProductrpt, "Product", ltlStatus, cmdDelete);
                }
                else
                {
                    IndicateNotUpdated(lProductrpt, "Product", ltlStatus);
                }
            }
            else
            {
                lProduct.Active = true;
                lProduct.AddedBy = UserName;
                lProduct.AddedDate = DateTime.Now;
                if ((lProductrpt.AddProduct(lProduct) != null))
                {
                    IndicateUpdated(lProductrpt, "Product", ltlStatus, cmdDelete);
                }
                else
                {
                    IndicateNotUpdated(lProductrpt, "Product", ltlStatus);
                }
            }
        }
    }

    protected void GoToProductList()
    {
        Response.Redirect("ManageProducts.aspx");
    }

    protected void DeleteProduct()
    {
        using (ProductsRepository lProductrpt = new ProductsRepository())
        {
            lProductrpt.DeleteProduct(lProductrpt.GetProductById(ProductId));
        }
        GoToProductList();
    }

    protected void cmdDelete_Click(object sender, EventArgs e)
    {
        DeleteProduct();
    }

    protected void cmdUpdate_Click(object sender, System.EventArgs e)
    {
        UpdateProduct();
    }

    protected void cmdCancel_Click(object sender, System.EventArgs e)
    {
        GoToProductList();
    }
}